@@ -98,13 +98,13 @@ class Relationship(Field):
         """
 
     @abstractmethod
-    def collection_remote_ids(self, query, local_ids=None):
+    def collection_remote_ids(self, local_ids):
         """Returns the SQL statement for the remote ids of a relationship's
         local collection.
         """
 
     @abstractmethod
-    def object_remote_ids(self, local_ids=None):
+    def object_remote_ids(self, local_ids=''):
         """Returns the SQL condition for an ?include parameter from an
         object.
         """
@@ -311,39 +311,12 @@ class OneToOneLocalRelationship(LocalRelationship, ToOneRelationship):
             f'FOREIGN KEY ({self.lfkey}) REFERENCES data.{self.rtable.name}(id)'
         ]
 
-    def collection_remote_ids(self, query, local_ids=None):
-        filters = query['filters']
-        page = query['page']
-        if local_ids is None and filters is None and page == {}:
-            partial = ''
-        else:
-            if filters:
-                where_clause = (
-                    f' WHERE '
-                    f'{" AND ".join(filters.conditions(self.collection))}')
-            else:
-                where_clause = ''
+    def collection_remote_ids(self, local_ids):
+        return (f'SELECT {self.lfkey} FROM data.{self.table.name} '
+                f'WHERE id IN ({local_ids})')
 
-            sort = query['sort']
-            if sort:
-                order_by_clause = f' ORDER BY {", ".join(sort)}'
-            else:
-                order_by_clause = ''
-
-            if page:
-                limit = page['size']
-                offset = page['number'] * limit
-                limit_offset_clause = f' LIMIT {limit} OFFSET {offset}'
-            else:
-                limit_offset_clause = ''
-
-            stmt = (f'SELECT id FROM data.{self.table.name}'
-                    f'{where_clause}{order_by_clause}{limit_offset_clause}')
-            partial = f' WHERE id IN ({stmt})'
-        return f'SELECT {self.lfkey} FROM data.{self.table.name}{partial}'
-
-    def object_remote_ids(self, local_ids=None):
-        if local_ids is None:
+    def object_remote_ids(self, local_ids=''):
+        if local_ids == '':
             partial = '=$1'
         else:
             partial = f' IN ({local_ids})'
@@ -374,39 +347,12 @@ class OneToOneRemoteRelationship(ToOneRelationship):
                 other.table is self.rtable and other.rtable is self.table and
                 other.lfkey == self.rfkey)
 
-    def collection_remote_ids(self, query, local_ids=None):
-        filters = query['filters']
-        page = query['page']
-        if local_ids is None and filters is None and page == {}:
-            where = f'WHERE {self.rfkey} IS NOT NULL'
-        else:
-            if filters:
-                where_clause = (
-                    f' WHERE '
-                    f'{" AND ".join(filters.conditions(self.collection))}')
-            else:
-                where_clause = ''
+    def collection_remote_ids(self, local_ids):
+        return (f'SELECT id FROM data.{self.rtable.name} '
+                f'WHERE {self.rfkey} IN ({local_ids})')
 
-            sort = query['sort']
-            if sort:
-                order_by_clause = f' ORDER BY {", ".join(sort)}'
-            else:
-                order_by_clause = ''
-
-            if page:
-                limit = page['size']
-                offset = page['number'] * limit
-                limit_offset_clause = f' LIMIT {limit} OFFSET {offset}'
-            else:
-                limit_offset_clause = ''
-
-            stmt = (f'SELECT id FROM data.{self.table.name}'
-                    f'{where_clause}{order_by_clause}{limit_offset_clause}')
-            where = f'WHERE {self.rfkey} IN ({stmt})'
-        return f'SELECT id FROM data.{self.rtable.name} {where}'
-
-    def object_remote_ids(self, local_ids=None):
-        if local_ids is None:
+    def object_remote_ids(self, local_ids=''):
+        if local_ids == '':
             partial = '=$1'
         else:
             partial = f' IN ({local_ids})'
@@ -769,39 +715,12 @@ class OneToManyRelationship(ToManyRelationship):
                 other.table is self.rtable and other.rtable is self.table and
                 other.lfkey == self.rfkey)
 
-    def collection_remote_ids(self, query, local_ids=None):
-        filters = query['filters']
-        page = query['page']
-        if local_ids is None and filters is None and page == {}:
-            where = f'WHERE {self.rfkey} IS NOT NULL'
-        else:
-            if filters:
-                where_clause = (
-                    f' WHERE '
-                    f'{" AND ".join(filters.conditions(self.collection))}')
-            else:
-                where_clause = ''
+    def collection_remote_ids(self, local_ids):
+        return (f'SELECT id FROM data.{self.rtable.name} '
+                f'WHERE {self.rfkey} IN ({local_ids})')
 
-            sort = query['sort']
-            if sort:
-                order_by_clause = f' ORDER BY {", ".join(sort)}'
-            else:
-                order_by_clause = ''
-
-            if page:
-                limit = page['size']
-                offset = page['number'] * limit
-                limit_offset_clause = f' LIMIT {limit} OFFSET {offset}'
-            else:
-                limit_offset_clause = ''
-
-            stmt = (f'SELECT id FROM data.{self.table.name}'
-                    f'{where_clause}{order_by_clause}{limit_offset_clause}')
-            where = f'WHERE {self.rfkey} IN ({stmt})'
-        return f'SELECT id FROM data.{self.rtable.name} {where}'
-
-    def object_remote_ids(self, local_ids=None):
-        if local_ids is None:
+    def object_remote_ids(self, local_ids=''):
+        if local_ids == '':
             partial = '=$1'
         else:
             partial = f' IN ({local_ids})'
@@ -1175,39 +1094,12 @@ class ManyToOneRelationship(LocalRelationship, ToOneRelationship):
             f'FOREIGN KEY ({self.lfkey}) REFERENCES data.{self.rtable.name}(id)'
         ]
 
-    def collection_remote_ids(self, query, local_ids=None):
-        filters = query['filters']
-        page = query['page']
-        if local_ids is None and filters is None and page == {}:
-            where = ''
-        else:
-            if filters:
-                where_clause = (
-                    f' WHERE '
-                    f'{" AND ".join(filters.conditions(self.collection))}')
-            else:
-                where_clause = ''
+    def collection_remote_ids(self, local_ids):
+        return (f'SELECT {self.lfkey} FROM data.{self.table.name} '
+                f'WHERE id IN ({local_ids})')
 
-            sort = query['sort']
-            if sort:
-                order_by_clause = f' ORDER BY {", ".join(sort)}'
-            else:
-                order_by_clause = ''
-
-            if page:
-                limit = page['size']
-                offset = page['number'] * limit
-                limit_offset_clause = f' LIMIT {limit} OFFSET {offset}'
-            else:
-                limit_offset_clause = ''
-
-            stmt = (f'SELECT id FROM data.{self.table.name}'
-                    f'{where_clause}{order_by_clause}{limit_offset_clause}')
-            where = f' WHERE id IN ({stmt})'
-        return f'SELECT {self.lfkey} FROM data.{self.table.name}{where}'
-
-    def object_remote_ids(self, local_ids=None):
-        if local_ids is None:
+    def object_remote_ids(self, local_ids=''):
+        if local_ids == '':
             partial = '=$1'
         else:
             partial = f' IN ({local_ids})'
@@ -1241,39 +1133,12 @@ class ManyToManyRelationship(ToManyRelationship):
                 other.atable is self.atable and other.lafkey == self.rafkey and
                 other.rafkey == self.lafkey)
 
-    def collection_remote_ids(self, query, local_ids=None):
-        filters = query['filters']
-        page = query['page']
-        if local_ids is None and filters is None and page == {}:
-            where = f'WHERE {self.lafkey} IS NOT NULL'
-        else:
-            if filters:
-                where_clause = (
-                    f' WHERE '
-                    f'{" AND ".join(filters.conditions(self.collection))}')
-            else:
-                where_clause = ''
+    def collection_remote_ids(self, local_ids):
+        return (f'SELECT {self.rafkey} FROM data.{self.atable.name} '
+                f'WHERE {self.lafkey} IN ({local_ids})')
 
-            sort = query['sort']
-            if sort:
-                order_by_clause = f' ORDER BY {", ".join(sort)}'
-            else:
-                order_by_clause = ''
-
-            if page:
-                limit = page['size']
-                offset = page['number'] * limit
-                limit_offset_clause = f' LIMIT {limit} OFFSET {offset}'
-            else:
-                limit_offset_clause = ''
-
-            stmt = (f'SELECT id FROM data.{self.table.name}'
-                    f'{where_clause}{order_by_clause}{limit_offset_clause}')
-            where = f'WHERE {self.lafkey} IN ({stmt})'
-        return f'SELECT {self.rafkey} FROM data.{self.atable.name} {where}'
-
-    def object_remote_ids(self, local_ids=None):
-        if local_ids is None:
+    def object_remote_ids(self, local_ids=''):
+        if local_ids == '':
             partial = '=$1'
         else:
             partial = f' IN ({local_ids})'
