@@ -58,10 +58,10 @@ from ajsonapi.postgres import (
     convert_violation_error,
 )
 from ajsonapi.query import (
+    FilterNode,
     parse_fields,
     parse_page,
     query_has_parameter,
-    subquery,
 )
 from ajsonapi.responses import document_response, no_content_response
 from ajsonapi.uri.resource import Resource
@@ -69,54 +69,6 @@ from ajsonapi.uri.resource import Resource
 RE_FILTER = re_compile(r'filter%5B([^%]*)%5D')
 
 
-class FilterNode:
-    """A FilterNode is a node in the 'field' tree from a resource.
-    It contains values for fields as well as paths to deeper fields.
-    """
-
-    # pylint: disable=too-few-public-methods
-
-    def __init__(self, attributes=None, relationships=None):
-        if attributes is None:
-            attributes = {}
-        if relationships is None:
-            relationships = {}
-        self.attributes = attributes
-        self.relationships = relationships
-
-    def __str__(self):
-        rels_str = {
-            key: str(value) for key, value in self.relationships.items()
-        }
-        return f'FilterNode({self.attributes}, {rels_str})'
-
-    def conditions(self, collection):
-        """Returns the SQL condition for this filter node."""
-
-        conds = []
-        for rel, sub_node in self.relationships.items():
-            sub_col = rel.rtable.collection
-            sub_conds = sub_node.conditions(sub_col)
-            where_clause = f'WHERE {" AND ".join(sub_conds)}'
-            conds.append(
-                rel.filter_condition(
-                    f'SELECT id FROM data.{rel.rtable.name} {where_clause}'))
-        for attr_name, values in self.attributes.items():
-            if attr_name == 'id':
-                id_values = {f"'{value}'" for value in values}
-                conds.append(f'id IN ({",".join(id_values)})')
-            else:
-                attr = getattr(collection.table.___, attr_name)
-                conds.append(f'{attr_name} IN ({attr.filter_values(values)})')
-        return conds
-
-    def remote(self, relationship):
-        """Returns the remote FilterNode."""
-        if relationship in self.relationships:
-            return self.relationships[relationship]
-        return None
-
-
 class Collection(Resource):
     """Class collection represents a resource collection."""
 
@@ -192,7 +144,7 @@ class Collection(Resource):
             self.includes_dict(query['includes'],
                                request_query['include'].split(','), errors, [])
         else:
-            query['includes'] = None
+            query['includes'] = {}
 
     def parse_filter(self, request_query, query, errors, allow):
         """Parses the request's filter query parameter."""
@@ -211,7 +163,7 @@ class Collection(Resource):
             query['filters'] = self.filters_tree(FilterNode(),
                                                  filter_path_values, errors, [])
         else:
-            query['filters'] = None
+            query['filters'] = FilterNode()
 
     def parse_sort(self, request_query, query, errors, allow):
         """Parses the request's sort query parameter."""
@@ -225,7 +177,7 @@ class Collection(Resource):
                 return
             query['sort'] = self.sort_list(request_query, errors)
         else:
-            query['sort'] = None
+            query['sort'] = []
 
     def includes_dict(self, include_dict, include_parameters, errors, path):
         """Helper function for parsing request query include parameters."""
@@ -536,7 +488,7 @@ class Collection(Resource):
             columns = (str(col) for col in self.table.columns)
 
         filters = env.query['filters']
-        if filters:
+        if not filters.is_leaf():
             where_clause = f' WHERE {" AND ".join(filters.conditions(self))}'
         else:
             where_clause = ''
@@ -681,12 +633,9 @@ class GetCollectionEnvironment:
         """Creates the environment for collecting the included member of the
         GET /{collection} response.
         """
-        if includes is None:
-            return
         for relationship, remote_includes in includes.items():
             remote_collection = relationship.rtable.collection
-            remote_ids = relationship.collection_remote_ids(
-                subquery(self.query, relationship), ids)
+            remote_ids = relationship.collection_remote_ids(ids)
             self.included_environments.append(
                 GetCollectionIncludedEnvironment(remote_collection, remote_ids,
                                                  self))
@@ -699,7 +648,31 @@ class GetCollectionEnvironment:
         """
 
         self.create_data_environment()
-        self.create_included_environments(None, self.query['includes'])
+
+        filters = self.query['filters']
+        if not filters.is_leaf():
+            where_clause = (
+                f' WHERE {" AND ".join(filters.conditions(self.collection))}')
+        else:
+            where_clause = ''
+
+        sort = self.query['sort']
+        if sort:
+            order_by_clause = f' ORDER BY {", ".join(sort)}'
+        else:
+            order_by_clause = ''
+
+        page = self.query['page']
+        if page:
+            limit = page['size']
+            offset = page['number'] * limit
+            limit_offset_clause = f' LIMIT {limit} OFFSET {offset}'
+        else:
+            limit_offset_clause = ''
+
+        ids = (f'SELECT id FROM data.{self.collection.table.name}'
+               f'{where_clause}{order_by_clause}{limit_offset_clause}')
+        self.create_included_environments(ids, self.query['includes'])
         self.tasks = [
             create_task(env.run()) for env in chain([self.data_environment],
                                                     self.included_environments)
@@ -740,11 +713,11 @@ class GetCollectionDataEnvironment:
         of a GET /{collection} response.
         """
         self.tasks = [create_task(self.collection.get_collection_data(self))]
-        query_fields = self.query['fields']
-        if self.collection in query_fields:
+        fields = self.query['fields']
+        if self.collection in fields:
             self.tasks.extend([
                 create_task(rel.get_collection_data(self))
-                for rel in query_fields[self.collection]
+                for rel in fields[self.collection]
                 if rel in self.collection.table.remote_relationships
             ])
         else:
