@@ -311,8 +311,6 @@ class GetObjectEnvironment:
         """Creates the environment for collecting the included member of the
         GET /{collection}/{id} response.
         """
-        if includes is None:
-            return
         for relationship, remote_includes in includes.items():
             remote_collection = relationship.rtable.collection
             remote_ids = relationship.object_remote_ids(ids)
@@ -329,7 +327,7 @@ class GetObjectEnvironment:
         """
 
         self.create_data_environment()
-        self.create_included_environments(None, self.query['includes'])
+        self.create_included_environments('', self.query['includes'])
         self.tasks = [
             create_task(env.run()) for env in chain([self.data_environment],
                                                     self.included_environments)
@@ -372,11 +370,11 @@ class GetObjectDataEnvironment:
         """
 
         self.tasks = [create_task(self.obj.get_object_data(self))]
-        query_fields = self.query['fields']
-        if self.obj.collection in query_fields:
+        fields = self.query['fields']
+        if self.obj.collection in fields:
             self.tasks.extend([
                 create_task(rel.get_object_data(self))
-                for rel in query_fields[self.obj.collection]
+                for rel in fields[self.obj.collection]
                 if rel in self.obj.table.remote_relationships
             ])
         else:
