@@ -157,12 +157,12 @@ class OneToOneLocalRelatedResource(ToOneRelatedResource):
     """
 
     async def get_related_data(self, env):
-        query_fields = env.query['fields']
+        fields = env.query['fields']
         rtable = self.relationship.rtable
-        if rtable.collection in query_fields:
+        if rtable.collection in fields:
             columns = chain(['id'], (str(col)
                                      for col in rtable.columns
-                                     if col in query_fields[rtable.collection]))
+                                     if col in fields[rtable.collection]))
         else:
             columns = (str(col) for col in rtable.columns)
         stmt = (f'SELECT {", ".join(columns)} '
@@ -190,12 +190,12 @@ class OneToOneRemoteRelatedResource(ToOneRelatedResource):
     """
 
     async def get_related_data(self, env):
-        query_fields = env.query['fields']
+        fields = env.query['fields']
         rtable = self.relationship.rtable
-        if rtable.collection in query_fields:
+        if rtable.collection in fields:
             columns = chain(['id'], (str(col)
                                      for col in rtable.columns
-                                     if col in query_fields[rtable.collection]))
+                                     if col in fields[rtable.collection]))
         else:
             columns = (str(col) for col in rtable.columns)
         # We could remove rfkey because we know it already.
@@ -221,12 +221,12 @@ class ManyToOneRelatedResource(ToOneRelatedResource):
     """
 
     async def get_related_data(self, env):
-        query_fields = env.query['fields']
+        fields = env.query['fields']
         rtable = self.relationship.rtable
-        if rtable.collection in query_fields:
+        if rtable.collection in fields:
             columns = chain(['id'], (str(col)
                                      for col in rtable.columns
-                                     if col in query_fields[rtable.collection]))
+                                     if col in fields[rtable.collection]))
         else:
             columns = (str(col) for col in self.relationship.rtable.columns)
         stmt = (f'SELECT {", ".join(columns)} '
@@ -313,18 +313,18 @@ class OneToManyRelatedResource(ToManyRelatedResource):
     """
 
     async def get_related_data(self, env):
-        query_fields = env.query['fields']
+        fields = env.query['fields']
         rtable = self.relationship.rtable
-        if rtable.collection in query_fields:
+        if rtable.collection in fields:
             columns = chain(['id'], (str(col)
                                      for col in rtable.columns
-                                     if col in query_fields[rtable.collection]))
+                                     if col in fields[rtable.collection]))
         else:
             columns = (str(col) for col in rtable.columns)
         # We could remove rfkey because we know it already
 
         filters = env.query['filters']
-        if filters:
+        if not filters.is_leaf():
             where_clause = (
                 f' WHERE {self.relationship.rfkey} = $1 AND '
                 f'{" AND ".join(filters.conditions(rtable.collection))}')
@@ -358,17 +358,17 @@ class ManyToManyRelatedResource(ToManyRelatedResource):
     """
 
     async def get_related_data(self, env):
-        query_fields = env.query['fields']
+        fields = env.query['fields']
         rtable = self.relationship.rtable
-        if rtable.collection in query_fields:
+        if rtable.collection in fields:
             columns = chain(['id'], (str(col)
                                      for col in rtable.columns
-                                     if col in query_fields[rtable.collection]))
+                                     if col in fields[rtable.collection]))
         else:
             columns = (str(col) for col in rtable.columns)
 
         filters = env.query['filters']
-        if filters:
+        if not filters.is_leaf():
             where_clause = (
                 f' WHERE id IN ('
                 f' SELECT {self.relationship.rafkey}'
@@ -429,8 +429,6 @@ class GetRelatedResourceEnvironment:
         """Creates the environment for collecting the included member of the
         GET /{collection}/{id}/{related_resource} response.
         """
-        if includes is None:
-            return
         for relationship, remote_includes in includes.items():
             remote_collection = relationship.rtable.collection
             remote_ids = relationship.object_remote_ids(ids)
@@ -540,12 +538,11 @@ class GetToOneRelatedResourceDataEnvironment(GetRelatedResourceDataEnvironment):
         related_resource corresponds to a to-one relationship.
         """
         self.tasks = [create_task(self.related.get_related_data(self))]
-        query_fields = self.query['fields']
-        if self.related.relationship.rtable.collection in query_fields:
+        fields = self.query['fields']
+        if self.related.relationship.rtable.collection in fields:
             self.tasks.extend([
                 create_task(rel.get_to_one_related_data(self))
-                for rel in query_fields[
-                    self.related.relationship.rtable.collection]
+                for rel in fields[self.related.relationship.rtable.collection]
                 if rel in self.related.relationship.rtable.remote_relationships
             ])
         else:
@@ -577,12 +574,11 @@ class GetToManyRelatedResourceDataEnvironment(GetRelatedResourceDataEnvironment
         related_resource corresponds to a to-many relationship.
         """
         self.tasks = [create_task(self.related.get_related_data(self))]
-        query_fields = self.query['fields']
-        if self.related.relationship.rtable.collection in query_fields:
+        fields = self.query['fields']
+        if self.related.relationship.rtable.collection in fields:
             self.tasks.extend([
                 create_task(rel.get_to_many_related_data(self))
-                for rel in query_fields[
-                    self.related.relationship.rtable.collection]
+                for rel in fields[self.related.relationship.rtable.collection]
                 if rel in self.related.relationship.rtable.remote_relationships
             ])
         else:
