@@ -770,8 +770,6 @@ class GetRelationshipEnvironment:
         """Creates the environment for collecting the included member of a
         GET /{collection}/{id}/relationships/{relationships} response.
         """
-        if includes is None:
-            return
         for relationship, remote_includes in includes.items():
             remote_collection = relationship.rtable.collection
             remote_ids = relationship.object_remote_ids(ids)
@@ -787,7 +785,7 @@ class GetRelationshipEnvironment:
         /{collection}/{id}/relationships/{relationship} response.
         """
         self.create_data_environment()
-        self.create_included_environments(None, self.query['includes'])
+        self.create_included_environments('', self.query['includes'])
         self.tasks = [
             create_task(env.run()) for env in chain([self.data_environment],
                                                     self.included_environments)
